pub enum RetryPolicy {
Count(u32),
Linear {
attempts: u32,
delay: Duration,
should_retry: Option<ShouldRetryFn>,
},
Exponential {
attempts: u32,
base_delay: Duration,
max_delay: Duration,
should_retry: Option<ShouldRetryFn>,
},
}Expand description
Retry policy configuration.
The attempts value is the maximum number of retries after the initial request.
For example, RetryPolicy::count(2) performs up to three HTTP calls (one initial + two retries).
Variants
Count(u32)
Shorthand for linear retry with attempts retries and a 1 second delay between attempts.
Linear
Exponential
Implementations
Sourceimpl RetryPolicy
impl RetryPolicy
pub fn count(attempts: u32) -> Self
pub fn linear(attempts: u32, delay: Duration) -> Self
pub fn exponential( attempts: u32, base_delay: Duration, max_delay: Duration, ) -> Self
pub fn with_should_retry(self, f: ShouldRetryFn) -> Self