Available on crate feature
tower only.Expand description
Helpers for building transport stacks with ServiceBuilder.
Structs
- Concurrency
Limit Layer - Enforces a limit on the concurrent number of requests the underlying service can handle.
- Rate
Limit Layer - Enforces a rate limit on the number of requests the underlying service can handle over a period of time.
- Service
Builder - Declaratively construct
Servicevalues. - Timeout
Layer - Applies a timeout to requests via the supplied inner service.
Traits
- Into
BoxHttp Service - Extension trait to box a configured service stack.
- Into
BoxStreaming Http Service - Extension trait to box a configured streaming service stack.
Functions
- build
- Builds a type-erased transport stack from a reqwest client and a configuration closure.
- build_
dual - Builds buffered and streaming transport stacks from one configuration closure.
- reqwest_
service - Creates a reqwest-backed inner service for layer stacking.
- with_
buffer - Wraps the reqwest inner service with
tower::buffer::Buffer. - with_
concurrency_ limit - Convenience: concurrency limit on the transport stack.
- with_
request_ logging - Logs each transport call at
DEBUG(wire-level; complementsLoggerPlugin).